import React, { Component } from 'react';
import './index.scss'
import Container from './container'
import SingleAnswerQuestion from "@components/interactive-tutorial/single-answer-question"
import Program from "@components/interactive-tutorial/program"
import Project from './project'
import { getParam, http, getWXObject } from "@/utils"
import { Toast } from 'antd-mobile'
import { questionType, status } from './consts'
import Catalog from './catalog'

class InteractiveStudy extends Component {
  singleIcon = 'https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/interactive_tutorial/study/single-answer-icon.png'
  programIcon = 'https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/interactive_tutorial/study/program-icon.png'
  state = {
    options: [
      'A. 程序向屏幕输出信息的过程，是人与计算机的单向沟通。',
      'B. 程序向内部输入信息的过程。',
      'C. 程序向内部输入信息的过程。',
    ],
    img: 'https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/weekend/bigdata/project/07.png',
    page: 1,
    schedule: {},
    pageData: {},
    processContent: [],
    processStatus: status.startPractice,
    isComplete: false,
  }

  componentDidMount() {

    this.getSchedule().then(res => {
      const {code, msg, data} = res.data
      if (code === 200) {

        this.setState({
          schedule: data,
        })
        this.getPageContent(data.current_video_id)

      } else {
        this.showToast(msg)
      }
    })
  }

  getSchedule = () => {
    return http.post(`${API.home}/m/it/study/schedule`, {
      course_id: getParam('id'),
    })
  }

  showToast = (msg, type = 'info') => {
    Toast[type](msg, 2, null, false)
  }

  getPageContent = (videoId) => {
    http.post(`${API.home}/m/it/study/syllabus?page=${this.state.page}`, {
      course_id: getParam('id'),
      video_id: videoId,
      type: 1,
    }).then(res => {
      const {code, msg, data} = res.data
      if (code === 200) {
        this.setState({
          pageData: data,
        })
      } else {
        this.showToast(msg)
      }
    })
  }

  render() {
    const {processStatus} = this.state
    return (
      <div id={'interactive-study'}>
        <Catalog title={'Print()函数'}/>
        <Container>
          <span className={'subtitle'}>副标题</span>
        </Container>
        <Container>
          <img
            src="https://timgsa.baidu.com/timg?image&quality=80&size=b9999_10000&sec=1590155695725&di=0a1cad792ef55dc43305ab904aae04fb&imgtype=0&src=http%3A%2F%2Fsearchfoto.ru%2Fimg%2FxyygpKbDS1y8pTjXUy83VS8rMS9fLSy3RL8mwz0yx9fcM0EtJ0S2PyCnOy8sOSTMOqQq38I23NHf0SHTNV0vMLbAutzUyNgCzMmwNzSGsomJbQzCjIDnHNgUMwNx8W1OIMNBoQz1DAA.jpg"
            alt=""/>
        </Container>
        <Container user={'https://julyedu-img-public.oss-cn-beijing.aliyuncs.com/Public/Image/home/avatar_20191104.png'}
                   content={'Hi！初次见面，我叫小柒，是你在七月在线的课程导师。从现在开始，你就要跟着我一起学Python啦，请敲回车键继续课程。'}/>
        <SingleAnswerQuestion user={this.singleIcon} topic={'请问，你会推荐哪个物品给用户C？'} options={this.state.options}
                              img={this.state.img}/>
        <Program user={this.programIcon} code={"week = ['星期一', '星期二', '星期三']\nprint(123)"}/>
        {/*<Project user={this.singleIcon}/>*/}
        <div className="status-bar">
          {/*<span className={'complete'}>已学完全部课时</span>*/}
          <span className={'status'}>{processStatus}</span>
          {/*<div className="free-trial-end">*/}
          {/*  <span>试学体验结束，389.1元学习全部课时</span>*/}
          {/*  <button className={'purchase'}>立即购买</button>*/}
          {/*</div>*/}
        </div>
      </div>
    );
  }
}

export default InteractiveStudy;